@@ -25,15 +25,16 @@ def run_gmagent(config: str, mod_path: str) -> None:
             "STRATEGYMOD": mod_path,
             "gm_strategyid": context.settings.gm_strategyid,
             "gm_token": context.settings.gm_token,
+            "mode": "LIVING",
         }
     )
     while True:
-        if vxtime.now() < vxtime.today("09:10:00"):
+        if vxtime.now() < vxtime.today("09:09:00"):
             logger.info("休眠等待第二天开盘时间.")
-            vxtime.sleep(vxtime.today("09:11:00") - vxtime.now())
+            vxtime.sleep(vxtime.today("09:10:00") - vxtime.now())
         elif vxtime.now() < vxtime.today("15:30:00"):
             try:
-                p = subprocess.run(
+                subprocess.run(
                     [sys.executable, "-m", "vxquant.agent.gmagent"],
                     env=_ENV,
                     shell=True,
@@ -46,7 +47,7 @@ def run_gmagent(config: str, mod_path: str) -> None:
 
         else:
             logger.info("休眠等待第二天开盘时间.")
-            vxtime.sleep(vxtime.today("09:11:00") + 60 * 60 * 24 - vxtime.now())
+            vxtime.sleep(vxtime.today("09:10:00") + 60 * 60 * 24 - vxtime.now())
 
 
 @storage("agent", "gmsimagent")
@@ -61,17 +62,51 @@ def run_gmsimagent(config: str, mod_path: str) -> None:
             "STRATEGYMOD": mod_path,
             "gm_strategyid": context.settings.gm_strategyid,
             "gm_token": context.settings.gm_token,
+            "mode": "SIM24",
         }
     )
 
     subprocess.run(
-        [sys.executable, "-m", "vxquant.agent.gmsimagent"],
+        [sys.executable, "-m", "vxquant.agent.gmagent"],
         env=_ENV,
         shell=True,
         check=True,
     )
 
 
+@storage("agent", "qmtagent")
+def run_qmtagent(config: str, mod_path: str) -> None:
+    """启动qmtagent"""
+    from vxquant.agent.qmtagent import run_qmtagent
+
+    while True:
+        if vxtime.now() < vxtime.today("09:09:00"):
+            logger.info("休眠等待第二天开盘时间.")
+            vxtime.sleep(vxtime.today("09:10:00") - vxtime.now())
+        elif vxtime.now() < vxtime.today("15:30:00"):
+            try:
+                subprocess.run(
+                    [
+                        sys.executable,
+                        "-m",
+                        "vxquant.agent.qmtagent",
+                        "-c",
+                        config,
+                        "-m",
+                        mod_path,
+                    ],
+                    shell=True,
+                    check=True,
+                )
+                vxtime.sleep(1)
+            except subprocess.CalledProcessError as e:
+                logger.warning(f"运行时错误: {e}")
+
+        else:
+            logger.info("休眠等待第二天开盘时间.")
+            vxtime.sleep(vxtime.today("09:10:00") + 60 * 60 * 24 - vxtime.now())
+
+
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description="""trade agent server""")
     parser.add_argument("-s", "--script", help="启动组件", default="gmagent")
