@@ -1,7 +1,5 @@
 """gmagent"""
 
-import os
-import pathlib
 
 try:
     from gm import api as gm_api
@@ -10,17 +8,19 @@ except ImportError:
     gm_api = None
     gmTdAPI = None
 
-from vxutils import logger, vxtime, to_timestamp, to_enum, to_timestring, vxWrapper
 
-from vxsched.triggers import vxDailyTrigger
-from vxsched import vxengine, vxContext
+import os
+import pathlib
+from vxutils import logger, vxtime, to_timestamp, to_enum, to_timestring
+from vxsched.triggers import vxDailyTrigger, vxOnceTrigger
+from vxsched import vxscheduler, vxContext
 from vxquant.model.exchange import OrderStatus, TradeStatus
 from vxquant.model.contants import AccountType
 from vxquant.model.preset import vxMarketPreset
 from vxquant.model.tools.gmData import gmOrderConvter, gmTradeConvter
 
 
-__all__ = ["run_gmagent", "init", "on_tick", "on_order_status", "on_execution_report"]
+__all__ = ["init", "on_tick", "on_order_status", "on_execution_report"]
 
 _default_gmagent_config = {
     "settings": {
@@ -56,23 +56,56 @@ _default_gmagent_config = {
         "subscriber": {},
     },
     "params": {},
+    "remote_orders": {},
+    "last_subscriber_time": 0,
+    "has_remote_event": False,
+    "publisher": "",
+    "subscriber": "",
 }
 
 
-def init(gmcontext):
-    """
-    掘金量化策略中必须有init方法,且策略会首先运行init定义的内容
-    """
+def setup_events(vxcontext):
+    # 订阅各种接口
+    tick_symbols = vxcontext.settings["tick_symbols"]
+    gm_api.subscribe(
+        tick_symbols,
+        "tick",
+    )
+    logger.info(f"订阅tick data: {tick_symbols}")
 
-    # 设置 时间函数
-    vxtime.set_timefunc(lambda: to_timestamp(gmcontext.now))
-    logger.info("=" * 80)
-    logger.info(f"{' 初始化开始 ':=^80}")
-    logger.info("=" * 80)
+    for event_type, run_time in vxcontext.settings["events"].items():
+        vxscheduler.submit_event(
+            event=event_type, trigger=vxDailyTrigger(run_time=run_time)
+        )
+        logger.info(f"订阅事件{event_type} 触发时间: {run_time}")
 
-    configfile = os.environ.get("GMCONFIGFILE", "gmagent.json")
+    gm_api.schedule(quit_simtrade, "1d", "16:30:00")
+    logger.info("设置退出时间 16:30:00")
+
+
+def setup_sim_events(vxcontext):
+    # 订阅各种接口
+    start_time = int(vxtime.now() + 3)
+    end_time = start_time + 30 * 60
+    vxscheduler.submit_event("before_trade", trigger=vxOnceTrigger(start_time))
+    vxscheduler.submit_event("on_trade", trigger=vxOnceTrigger(start_time + 60))
+    vxscheduler.submit_event(
+        "before_close", trigger=vxOnceTrigger(start_time + 60 * 20)
+    )
+    vxscheduler.submit_event("on_close", trigger=vxOnceTrigger(start_time + 60 * 22))
+    vxscheduler.submit_event("after_close", trigger=vxOnceTrigger(start_time + 60 * 25))
+
+    for i in range(start_time, end_time, 3):
+        run_time = to_timestring(i, "%H:%M:%S")
+        gm_api.schedule(on_tick, "1d", run_time)
+        # logger.info(f"设定on_tick时间: {run_time}")
+
+    gm_api.schedule(quit_simtrade, "1d", to_timestring(end_time, "%H:%M:%S"))
+    logger.info("设置全天消息事件，测试市场30分钟.")
+
+
+def init_context(gmcontext, configfile):
     vxcontext = vxContext.load_json(configfile, _default_gmagent_config)
-    mod_path = os.environ.get("STRATEGYMOD", "mod/")
 
     # 拷贝context内容只gmcontext中
     for k, v in vxcontext.items():
@@ -95,58 +128,47 @@ def init(gmcontext):
         f"检查下单接口是否正常: 账户({account.account_id}) 类型: {account_type} 净资产:"
         f" {account.nav:,.2f}元."
     )
+    return gmcontext
 
-    if gmcontext.settings.publisher and gmcontext.settings.subscriber:
-        gmcontext.publisher = vxWrapper.init_by_config(gmcontext.settings.publisher)
-        logger.info(f"设置publisher: {gmcontext.publisher}")
-        gmcontext.subscriber = vxWrapper.init_by_config(gmcontext.settings.subscriber)
-        logger.info(f"设置subscriber: {gmcontext.subscriber}")
-        gmcontext.has_remote_event = True
-        logger.info("开启接送和发送远端消息事件模式...")
-        gmcontext.last_subscriber_time = 0
+
+def init(gmcontext):
+    """
+    掘金量化策略中必须有init方法,且策略会首先运行init定义的内容
+    """
+
+    # 设置 时间函数
+    vxtime.set_timefunc(lambda: to_timestamp(gmcontext.now))
+    logger.info("=" * 80)
+    logger.info(f"{' 初始化开始 ':=^80}")
+    logger.info("=" * 80)
+
+    configfile = os.environ.get("GMCONFIGFILE", "gmagent.json")
+    mod_path = os.environ.get("STRATEGYMOD", "mod/")
+    mode = os.environ.get("mode", "LIVING")
+    init_context(gmcontext, configfile)
+    if mode != "LIVING":
+        setup_sim_events(gmcontext)
     else:
-        gmcontext.publisher = None
-        gmcontext.subscriber = None
-        gmcontext.has_remote_event = False
-        logger.info("关闭接受和发送远端消息时间...")
+        setup_events(gmcontext)
 
-    # 订阅各种接口
-    tick_symbols = vxcontext.settings["tick_symbols"]
-    gm_api.subscribe(
-        tick_symbols,
-        "tick",
-    )
-    logger.info(f"订阅tick data: {tick_symbols}")
-
-    for event_type, run_time in vxcontext.settings["events"].items():
-        vxengine.submit_event(
-            event=event_type, trigger=vxDailyTrigger(run_time=run_time)
+    if pathlib.Path(__file__).parent.joinpath("mod/").is_dir():
+        vxscheduler.load_modules(
+            pathlib.Path(__file__).parent.joinpath("mod/").as_posix()
         )
-        logger.info(f"订阅事件{event_type} 触发时间: {run_time}")
 
-    gm_api.schedule(quit_simtrade, "1d", "16:30:00")
-    logger.info("设置退出时间 16:30:00")
+    if mod_path and pathlib.Path(mod_path).is_dir():
+        vxscheduler.load_modules(mod_path)
 
-    vxengine.load_modules(mod_path)
-    vxengine.initialize(context=gmcontext)
+    vxscheduler.initialize(context=gmcontext)
 
     logger.info("=" * 80)
     logger.info(f"{' 初始化完成 ':=^80}")
     logger.info("=" * 80)
 
-    if vxtime.today("09:15:00") < vxtime.now() < vxtime.today("15:00:00"):
-        vxengine.submit_event("before_trade")
-        logger.warning("当前为开盘时间，触发一次before_trade。")
-        vxengine.trigger_events()
-
 
 def on_tick(gmcontext, gmtick=None):
     """on tick"""
-    if gmcontext.has_remote_event and gmcontext.last_subscriber_time + 1 < vxtime.now():
-        list(map(vxengine.submit_event, gmcontext.subscriber()))
-        gmcontext.last_subscriber_time = vxtime.now()
-
-    vxengine.trigger_events()
+    vxscheduler.trigger_events()
 
 
 def on_order_status(gmcontext, order):
@@ -162,10 +184,8 @@ def on_order_status(gmcontext, order):
     if vxorder.exchange_order_id not in gmcontext.broker_orders:
         gmcontext.broker_orders[vxorder.exchange_order_id] = vxorder
         logger.info(f"[新增] 委托订单{vxorder.exchange_order_id} 更新为: {vxorder}")
-        vxengine.submit_event("on_broker_order_status", vxorder)
-        vxengine.trigger_events()
-        if gmcontext.has_remote_event:
-            gmcontext.publisher("on_broker_order_status", vxorder)
+        vxscheduler.submit_event("on_broker_order_status", vxorder)
+        vxscheduler.trigger_events()
         return
 
     broker_order = gmcontext.broker_orders[vxorder.exchange_order_id]
@@ -177,14 +197,14 @@ def on_order_status(gmcontext, order):
         OrderStatus.Canceled,
         OrderStatus.Suspended,
     ]:
-        logger.warning(
+        logger.debug(
             f"[忽略更新] 委托订单 {vxorder.exchange_order_id} "
             f" 当前状态:{broker_order.status} 须更新状态: {vxorder.status}"
         )
         return
 
     if broker_order.filled_volume > vxorder.filled_volume:
-        logger.warning(
+        logger.debug(
             f"[忽略更新] 委托订单 {vxorder.exchange_order_id} 当前已成交:"
             f" {broker_order.filled_volume} > 更新状态:{vxorder.filled_volume}"
         )
@@ -196,11 +216,9 @@ def on_order_status(gmcontext, order):
     broker_order.filled_amount = vxorder.filled_amount
     broker_order.updated_dt = vxorder.updated_dt
     gmcontext.broker_orders[broker_order.exchange_order_id] = broker_order
-    vxengine.submit_event("on_broker_order_status", broker_order)
     logger.info(f"[更新] 委托订单{vxorder.exchange_order_id} 更新为: {broker_order}")
-    vxengine.trigger_events()
-    if gmcontext.has_remote_event:
-        gmcontext.publisher("on_broker_order_status", vxorder)
+    vxscheduler.submit_event("on_broker_order_status", broker_order)
+    vxscheduler.trigger_events()
 
 
 def on_execution_report(gmcontext, execrpt):
@@ -239,41 +257,19 @@ def on_execution_report(gmcontext, execrpt):
         return
 
     gmcontext.broker_trades[vxtrade.trade_id] = vxtrade
-    if gmcontext.has_remote_event:
-        gmcontext.publisher("on_broker_order_status", vxtrade)
-    vxengine.submit_event("on_broker_order_status", vxtrade)
+    vxscheduler.submit_event("on_broker_execution_report", vxtrade)
     logger.info(f"收到成交回报信息: {vxtrade}")
-    vxengine.trigger_events()
-    if gmcontext.has_remote_event:
-        gmcontext.publisher("on_broker_order_status", vxtrade)
-
-
-def save_config(gmcontext, configfile):
-    config = vxContext(_default_gmagent_config)
-    config["settings"].update(gmcontext.settings)
-    config["params"].update(gmcontext.params)
-    config.save_json(configfile)
-    logger.info(f"保存最新的配置文件内容:{configfile}")
+    vxscheduler.trigger_events()
 
 
 def quit_simtrade(gmcontext):
     """退出时调用"""
-
     configfile = os.environ.get("GMCONFIGFILE", "gmagent.json")
-    save_config(gmcontext, configfile)
-    logger.warning("=" * 80)
-    logger.warning("{' 当天交易结束 ':*^80}")
-    logger.warning("=" * 80)
-
+    vxscheduler.submit_event("on_exit", data=configfile)
+    vxscheduler.trigger_events()
     gm_api.stop()
 
 
-def on_trade_data_disconnected(gmcontext):
-    """当交易网络断开的时候，保存配置文件"""
-    configfile = os.environ.get("GMCONFIGFILE", "gmagent.json")
-    save_config(gmcontext, configfile)
-
-
 if __name__ == "__main__":
     gm_strategyid = os.environ.get("gm_strategyid", None)
     gm_token = os.environ.get("gm_token", None)
