@@ -3,7 +3,7 @@
 import argparse
 import pathlib
 from vxutils import logger, storage
-from vxsched import vxengine, vxContext
+from vxsched import vxscheduler, vxContext
 
 from vxsched.scripts import *
 
@@ -16,11 +16,11 @@ def run_scheduler(config=None, mod_path=None):
         logger.info(f"loading config file: {config}")
         context = vxContext.load_json(config, _default_context)
     else:
-        context = vxContext()
+        context = vxContext(_default_context)
 
-    vxengine.load_modules(mod_path)
-    vxengine.initialize(context=context)
-    vxengine.serve_forever()
+    vxscheduler.load_modules(mod_path)
+    vxscheduler.initialize(context=context)
+    vxscheduler.serve_forever()
 
 
 if __name__ == "__main__":
@@ -45,6 +45,7 @@ if __name__ == "__main__":
     if args.verbose:
         logger.setLevel("DEBUG")
 
-    run_func = storage.get("scheduler", args.script)
+    # run_func = storage.get("scheduler", args.script)
 
-    run_func(config=args.config, mod_path=args.mod)
+    # run_func(config=args.config, mod_path=args.mod)
+    vxscheduler.server_forever(config=args.config, mod=args.mod)
