@@ -17,7 +17,7 @@ from pathlib import Path
 from enum import Enum
 from collections.abc import MutableMapping, Mapping, Sequence
 from typing import Any, Callable, Optional, List, Dict
-
+from operator import getitem
 from vxutils import (
     vxtime,
     vxJSONEncoder,
@@ -444,16 +444,24 @@ def _(obj):
 class vxDataConvertor:
     """数据转换器基础类"""
 
-    def __init__(self, target_cls, rename_dict: MutableMapping = None) -> None:
+    def __init__(
+        self,
+        target_cls,
+        convertors_mapping: MutableMapping = None,
+        defaults: MutableMapping = None,
+    ) -> None:
         self._target_cls = target_cls
         self._convertors = {}
-        self._defaults_data = {}
+        self._defaults_data = defaults or {}
 
-        if rename_dict is None:
+        if convertors_mapping is None:
             return
 
-        for target_col, source_col in rename_dict.items():
-            self.rename_columns(source_col=source_col, target_col=target_col)
+        for target_col, convertor in convertors_mapping.items():
+            if callable(convertor):
+                self.add_convertors(target_col, convertor)
+            else:
+                self.rename_columns(convertor, target_col)
 
     def add_convertors(self, target_col, conveter_func):
         """设置col的转换函数
@@ -480,31 +488,37 @@ class vxDataConvertor:
         """设置默认值"""
         self._defaults_data[target_col] = default_value
 
+    def _convert_col(self, col, other_data):
+        try:
+            col_value = self._defaults_data.get(col, None)
+            if col in self._convertors:
+                col_value = self._convertors[col](other_data)
+            elif hasattr(other_data, col):
+                col_value = getattr(other_data, col)
+            else:
+                col_value = getitem(other_data, col)
+        except Exception as err:
+            from vxutils import logger
+
+            logger.debug(
+                (
+                    f"target class: {self._target_cls.__name__} Other_data load"
+                    f" col:{col} err. {err}"
+                ),
+                exc_info=True,
+            )
+            logger.debug(f"other_data={other_data}")
+
+        return col, col_value
+
     def __call__(self, other_data, key="", **kwargs):
         data = {}
-
-        def _convert_col(col):
-            try:
-                if col in self._convertors:
-                    return col, self._convertors[col](other_data)
-                elif hasattr(other_data, col):
-                    return col, getattr(other_data, col)
-                else:
-                    with contextlib.suppress(KeyError):
-                        return col, other_data[col]
-
-            except Exception as err:
-                from vxutils import logger
-
-                logger.error(
-                    f"target class: {self._target_cls.__name__} Other_data load"
-                    f" col:{col} err. {err}",
-                    exc_info=True,
-                )
-                logger.debug(f"other_data={other_data}")
-            return col, self._defaults_data.get(col, None)
-
-        data.update(map(_convert_col, self._target_cls.__vxfields__))
+        data.update(
+            map(
+                lambda col: self._convert_col(col, other_data),
+                self._target_cls.__vxfields__,
+            )
+        )
         data.update(**kwargs)
 
         instance = self._target_cls(**data)
