@@ -94,9 +94,9 @@ def timeit(func):
     """
 
     def wapper(*args, **kwargs):
-        _start = time.time()
+        _start = time.perf_counter()
         retval = func(*args, **kwargs)
-        _end = time.time()
+        _end = time.perf_counter()
         print(f"function {func.__name__}() used : {(_end - _start):.6f)}s")
         return retval
 
@@ -285,4 +285,3 @@ class storage:
     @classmethod
     def get(cls, type_name: str, element_name: str) -> Any:
         return cls.__elements[type_name][element_name]
-
